@@ -49,17 +49,6 @@ def text_decorate(string: str, decoration: str="BOLD"):
     endd = ansi["END"]
     return f"{text_dec}{string}{endd}"
 
-
-def another() -> str:
-    """FDAJF"""
-    print("NAH")
-    return "NAH"
-
-def test_subby(test: str) -> str:
-    """RESAD """
-    print("HI", test)
-    return f"HI {test}"
-
 def get_funcs():
     l = []
     for key, value in globals().items():
@@ -91,7 +80,7 @@ def has_args(type_dict: dict, args: list):
         print(type_dict)
         return True
 
-def cli(args: list, def_cmd=cli_help):
+def cly(args: list, def_cmd=cli_help):
     if len(args) == 1:
         def_cmd()
         return True
@@ -106,8 +95,6 @@ def cli(args: list, def_cmd=cli_help):
     else:
         print(args, "doesn't contain a valid sub_cmd")
 
-def main(args: list):
-    cli(args)
 
 if __name__ == "__main__":
-    main(sys.argv)
+    cly(sys.argv)
